/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2010 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Application
    scalarTransportFoam

Description
    Solves a transport equation for a passive scalar

\*---------------------------------------------------------------------------*/

#include "fvCFD.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

int main(int argc, char *argv[])
{

#   include "setRootCase.H"

#   include "createTime.H"
#   include "createMesh.H"
#   include "createFields.H"


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

    Info<< "\nCalculating scalar transport\n" << endl;

#   include "CourantNo.H"

        Info<< endl;
        Info<< "------------------------------" << nl << endl;
        Info<< "fvMesh stroed data"             << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "Cell volume V() = "             << mesh.V() << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "Face area vectors Sf() = "      << mesh.Sf() << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "Face area magnitudes |Sf|() = " << mesh.magSf() << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "Cell centers C() = "            << mesh.C() << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "Face centers Cf() = "           << mesh.Cf() << nl << endl;
        Info<< "-------------------" << nl << endl;

        Info<< nl << endl;
        Info<< "------------------------------" << nl << endl;
        Info<< "Discretisation data"             << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "Time = " << runTime.timeName() << "  deltaT = " << runTime.deltaT().value() << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "U = " << U << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "interpolate(U) = " << fvc::interpolate(U) << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "fvc::surfaceIntegrate(interpolate(U)&Sf) = " << fvc::surfaceIntegrate(fvc::interpolate(U)&mesh.Sf()) << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "fvc::div(U) = " << fvc::div(U) << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "Create phi: phi = interpolate(U)&Sf (&: Inner product)" << nl << endl;
        Info<< "interpolate(U)&Sf = " << (fvc::interpolate(U)&mesh.Sf()) << nl << endl;
        Info<< "-------------------" << nl << endl;
                phi = fvc::interpolate(U)&mesh.Sf();
        Info<< "phi = " << phi << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "fvc::surfaceIntegrate(phi*interpolate(U)) = " << fvc::surfaceIntegrate(phi*fvc::interpolate(U)) << nl << endl;
        Info<< "-------------------" << nl << endl;
        Info<< "fvc::div(phi,U) = " << fvc::div(phi,U) << nl << endl;
        Info<< "-------------------" << nl << endl;

        for(int n=1; n<=1; n++){
          Info<< "solve(fvm::ddt(U) == fvc::div(phi,U))" << nl << endl;
            solve(fvm::ddt(U) == fvc::div(phi,U));  runTime++;
          Info<< "-------------------" << nl << endl;
          Info<< "Time = " << runTime.timeName() << "  deltaT = " << runTime.deltaT().value() << nl << endl;
          Info<< "-------------------" << nl << endl;
          Info<< "U = " << U << nl << endl;
          Info<< "-------------------" << nl << endl;
          Info<< "Create phi: phi = interpolate(U)&Sf (&: Inner product)" << nl << endl;
          Info<< "interpolate(U)&Sf = " << (fvc::interpolate(U)&mesh.Sf()) << nl << endl;
          Info<< "-------------------" << nl << endl;
                  phi = fvc::interpolate(U)&mesh.Sf();
          Info<< "phi = " << phi << nl << endl;
          Info<< "-------------------" << nl << endl;
          Info<< "fvc::div(phi,U) = " << fvc::div(phi,U) << nl << endl;
          Info<< "-------------------" << nl << endl;
        }

    Info<< "End\n" << endl;

    return 0;
}


// ************************************************************************* //
